@@ -113,31 +113,105 @@ from .version import __version__, __dapodik_version__  # NOQA
 
 from .dapodik import Dapodik
 
-__author__ = 'hexatester (Habib Rohman)'
+__author__ = "hexatester (Habib Rohman)"
 
 __all__ = [
-    'Agama', 'Akreditasi', 'AkreditasiSp', 'AksesInternet', 'Alat',
-    'AlatDariBlockgrant', 'AlatLongitudinal', 'AlatTransportasi', 'Angkutan',
-    'AngkutanDariBlockgrant', 'BaseAuth', 'Bangunan', 'BangunanDariBlockgrant',
-    'BangunanLongitudinal', 'Bank', 'BaseCustomrest', 'BaseDapodik',
-    'BaseJadwal', 'BasePesertaDidik', 'BasePtk', 'BaseRest',
-    'BaseRombonganBelajar', 'BaseSarpras', 'BaseSekolah', 'BentukLembaga',
-    'Biblio', 'BlockGrant', 'Buku', 'BukuLongitudinal', 'ChildDelete',
-    'Dapodik', 'DapodikObject', 'Jadwal', 'FasilitasLayanan', 'Gmd',
-    'JadwalPaud', 'JenisGugus', 'JenisHapusBuku', 'JenisKeluar', 'JenisLk',
-    'JenisPendaftaran', 'JenisPrasarana', 'JenisPtk', 'JenisRombel',
-    'JenisSarana', 'JenisTinggal', 'JenjangPendidikan', 'Jurusan', 'JurusanSp',
-    'KategoriTk', 'KeahlianLaboratorium', 'KebutuhanKhusus', 'Kepanitiaan',
-    'KlasifikasiLembaga', 'Kurikulum', 'LembagaPengangkat', 'MataPelajaran',
-    'MataPelajaranKurikulum', 'MstWilayah', 'PangkatGolongan', 'Pekerjaan',
-    'Pembelajaran', 'Pengguna', 'Penghasilan', 'PesertaDidik',
-    'PesertaDidikBaru', 'PesertaDidikLongitudinal', 'ProgramInklusi', 'Ptk',
-    'PtkTerdaftar', 'RegistrasiPesertaDidik', 'Rest', 'Results',
-    'RolePengguna', 'RombonganBelajar', 'Ruang', 'RuangLongitudinal',
-    'Sanitasi', 'Sekolah', 'SekolahLongitudinal', 'SekolahPaud', 'Semester',
-    'StatusKeaktifanPegawai', 'StatusKepegawaian', 'StatusKepemilikanSarpras',
-    'SumberAir', 'SumberDanaSekolah', 'SumberGaji', 'SumberListrik', 'SyncLog',
-    'TahunAjaran', 'Tanah', 'TanahLongitudinal', 'TanahDariBlockgrant',
-    'TingkatPendidikan', 'UpdatePanelDashboard', 'WaktuPenyelenggaraan',
-    'Yayasan'
+    "Agama",
+    "Akreditasi",
+    "AkreditasiSp",
+    "AksesInternet",
+    "Alat",
+    "AlatDariBlockgrant",
+    "AlatLongitudinal",
+    "AlatTransportasi",
+    "Angkutan",
+    "AngkutanDariBlockgrant",
+    "BaseAuth",
+    "Bangunan",
+    "BangunanDariBlockgrant",
+    "BangunanLongitudinal",
+    "Bank",
+    "BaseCustomrest",
+    "BaseDapodik",
+    "BaseJadwal",
+    "BasePesertaDidik",
+    "BasePtk",
+    "BaseRest",
+    "BaseRombonganBelajar",
+    "BaseSarpras",
+    "BaseSekolah",
+    "BentukLembaga",
+    "Biblio",
+    "BlockGrant",
+    "Buku",
+    "BukuLongitudinal",
+    "ChildDelete",
+    "Dapodik",
+    "DapodikObject",
+    "Jadwal",
+    "FasilitasLayanan",
+    "Gmd",
+    "JadwalPaud",
+    "JenisGugus",
+    "JenisHapusBuku",
+    "JenisKeluar",
+    "JenisLk",
+    "JenisPendaftaran",
+    "JenisPrasarana",
+    "JenisPtk",
+    "JenisRombel",
+    "JenisSarana",
+    "JenisTinggal",
+    "JenjangPendidikan",
+    "Jurusan",
+    "JurusanSp",
+    "KategoriTk",
+    "KeahlianLaboratorium",
+    "KebutuhanKhusus",
+    "Kepanitiaan",
+    "KlasifikasiLembaga",
+    "Kurikulum",
+    "LembagaPengangkat",
+    "MataPelajaran",
+    "MataPelajaranKurikulum",
+    "MstWilayah",
+    "PangkatGolongan",
+    "Pekerjaan",
+    "Pembelajaran",
+    "Pengguna",
+    "Penghasilan",
+    "PesertaDidik",
+    "PesertaDidikBaru",
+    "PesertaDidikLongitudinal",
+    "ProgramInklusi",
+    "Ptk",
+    "PtkTerdaftar",
+    "RegistrasiPesertaDidik",
+    "Rest",
+    "Results",
+    "RolePengguna",
+    "RombonganBelajar",
+    "Ruang",
+    "RuangLongitudinal",
+    "Sanitasi",
+    "Sekolah",
+    "SekolahLongitudinal",
+    "SekolahPaud",
+    "Semester",
+    "StatusKeaktifanPegawai",
+    "StatusKepegawaian",
+    "StatusKepemilikanSarpras",
+    "SumberAir",
+    "SumberDanaSekolah",
+    "SumberGaji",
+    "SumberListrik",
+    "SyncLog",
+    "TahunAjaran",
+    "Tanah",
+    "TanahLongitudinal",
+    "TanahDariBlockgrant",
+    "TingkatPendidikan",
+    "UpdatePanelDashboard",
+    "WaktuPenyelenggaraan",
+    "Yayasan",
 ]
