@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('pengguna_id')
-@dataclass(eq=False)
+@set_meta("pengguna_id")
+@attr.dataclass
 class Pengguna(DapodikObject):
     pengguna_id: str
     sekolah_id: str
