@@ -1,16 +1,24 @@
-from dataclasses import dataclass
-from dapodik import (DapodikObject, Semester, Ruang, TingkatPendidikan,
-                     Pembelajaran, Sekolah)
+import attr
+from dapodik import (
+    DapodikObject,
+    Semester,
+    Ruang,
+    TingkatPendidikan,
+    Pembelajaran,
+    Sekolah,
+)
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('jadwal_id',
-          sekolah=Sekolah,
-          semester=Semester,
-          pembelajaran=Pembelajaran,
-          tingkat_pendidikan=TingkatPendidikan,
-          ruang=Ruang)
-@dataclass(eq=False)
+@set_meta(
+    "jadwal_id",
+    sekolah=Sekolah,
+    semester=Semester,
+    pembelajaran=Pembelajaran,
+    tingkat_pendidikan=TingkatPendidikan,
+    ruang=Ruang,
+)
+@attr.dataclass
 class Jadwal(DapodikObject):
     jadwal_id: str
     sekolah_id: str
