@@ -1,14 +1,14 @@
-from dataclasses import dataclass
+import attr
 from dapodik import DapodikObject, PesertaDidik, Semester
 from dapodik.utils.decorator import set_meta
 
 DEF = "Admin.model.PesertaDidikLongitudinal-1"
 
 
-@set_meta('peserta_didik_longitudinal_id',
-          peserta_didik=PesertaDidik,
-          semester=Semester)
-@dataclass(eq=False)
+@set_meta(
+    "peserta_didik_longitudinal_id", peserta_didik=PesertaDidik, semester=Semester
+)
+@attr.dataclass
 class PesertaDidikLongitudinal(DapodikObject):
     peserta_didik_id: int
     tinggi_badan: int
