@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('agama_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("agama_id")
+@attr.dataclass(frozen=True)
 class Agama(DapodikObject):
     agama_id: int
     nama: str
