@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_hapus_buku')
-@dataclass(eq=False, frozen=True)
+@set_meta("id_hapus_buku")
+@attr.dataclass(frozen=True)
 class JenisHapusBuku(DapodikObject):
     id_hapus_buku: str
     ket_hapus_buku: str
