@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('jenis_ptk_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("jenis_ptk_id")
+@attr.dataclass(frozen=True)
 class JenisPtk(DapodikObject):
     jenis_ptk_id: str
     jenis_ptk: str
