@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('kode_wilayah')
-@dataclass(eq=False, frozen=True)
+@set_meta("kode_wilayah")
+@attr.dataclass(frozen=True)
 class MstWilayah(DapodikObject):
     kode_wilayah: str
     nama: str
