@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_role_pengguna')
-@dataclass(eq=False, frozen=True)
+@set_meta("id_role_pengguna")
+@attr.dataclass(frozen=True)
 class RolePengguna(DapodikObject):
     id_role_pengguna: str
     sekolah_id: str
