@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('status_kepegawaian_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("status_kepegawaian_id")
+@attr.dataclass(frozen=True)
 class StatusKepegawaian(DapodikObject):
     status_kepegawaian_id: int
     nama: str
