@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('kepemilikan_sarpras_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("kepemilikan_sarpras_id")
+@attr.dataclass(frozen=True)
 class StatusKepemilikanSarpras(DapodikObject):
     kepemilikan_sarpras_id: str
     nama: str
