@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from dapodik import DapodikObject
 from typing import Optional
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('sumber_listrik_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("sumber_listrik_id")
+@attr.dataclass(frozen=True)
 class SumberListrik(DapodikObject):
     sumber_listrik_id: str
     nama: str
