@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime, date
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('tahun_ajaran_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("tahun_ajaran_id")
+@attr.dataclass(frozen=True)
 class TahunAjaran(DapodikObject):
     tahun_ajaran_id: str
     nama: str
