@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('tingkat_pendidikan_id')
-@dataclass(eq=False, frozen=True)
+@set_meta("tingkat_pendidikan_id")
+@attr.dataclass(frozen=True)
 class TingkatPendidikan(DapodikObject):
     tingkat_pendidikan_id: str
     kode: str
