@@ -1,15 +1,22 @@
-from dataclasses import dataclass
-from dapodik import (DapodikObject, Semester, PtkTerdaftar, MataPelajaran,
-                     RombonganBelajar)
+import attr
+from dapodik import (
+    DapodikObject,
+    Semester,
+    PtkTerdaftar,
+    MataPelajaran,
+    RombonganBelajar,
+)
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('pembelajaran_id',
-          rombongan_belajar=RombonganBelajar,
-          mata_pelajaran=MataPelajaran,
-          ptk_terdaftar=PtkTerdaftar,
-          semester=Semester)
-@dataclass(eq=False)
+@set_meta(
+    "pembelajaran_id",
+    rombongan_belajar=RombonganBelajar,
+    mata_pelajaran=MataPelajaran,
+    ptk_terdaftar=PtkTerdaftar,
+    semester=Semester,
+)
+@attr.dataclass
 class Pembelajaran(DapodikObject):
     rombongan_belajar_id: str
     status_di_kurikulum_str: str
