@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Sekolah, JenisSarana, Ptk
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_alat', jenis_sarana=JenisSarana, sekolah=Sekolah, ptk=Ptk)
-@dataclass(eq=False)
+@set_meta("id_alat", jenis_sarana=JenisSarana, sekolah=Sekolah, ptk=Ptk)
+@attr.dataclass
 class Alat(DapodikObject):
     id_alat: str
     jenis_sarana_id: int
