@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, BlockGrant
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('angkutan_dari_blockgrant_id', blockgrant=BlockGrant)
-@dataclass(eq=False)
+@set_meta("angkutan_dari_blockgrant_id", blockgrant=BlockGrant)
+@attr.dataclass
 class AngkutanDariBlockgrant(DapodikObject):
     blockgrant_id: str
     id_angkutan: str
