@@ -1,18 +1,26 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import (DapodikObject, Sekolah, MataPelajaran, TingkatPendidikan,
-                     Ruang, Biblio)
+from dapodik import (
+    DapodikObject,
+    Sekolah,
+    MataPelajaran,
+    TingkatPendidikan,
+    Ruang,
+    Biblio,
+)
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_buku',
-          mata_pelajaran=MataPelajaran,
-          sekolah=Sekolah,
-          tingkat_pendidikan=TingkatPendidikan,
-          ruang=Ruang,
-          biblio=Biblio)
-@dataclass(eq=False)
+@set_meta(
+    "id_buku",
+    mata_pelajaran=MataPelajaran,
+    sekolah=Sekolah,
+    tingkat_pendidikan=TingkatPendidikan,
+    ruang=Ruang,
+    biblio=Biblio,
+)
+@attr.dataclass
 class Buku(DapodikObject):
     id_buku: str
     mata_pelajaran_id: int
