@@ -1,15 +1,14 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Sekolah, JenisPrasarana, Bangunan
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('id_ruang',
-          jenis_prasarana=JenisPrasarana,
-          sekolah=Sekolah,
-          bangunan=Bangunan)
-@dataclass(eq=False)
+@set_meta(
+    "id_ruang", jenis_prasarana=JenisPrasarana, sekolah=Sekolah, bangunan=Bangunan
+)
+@attr.dataclass
 class Ruang(DapodikObject):
     id_ruang: str
     jenis_prasarana_id: int
