@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Semester, Ruang
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('ruang_longitudinal_id', semester=Semester, ruang=Ruang)
-@dataclass(eq=False)
+@set_meta("ruang_longitudinal_id", semester=Semester, ruang=Ruang)
+@attr.dataclass
 class RuangLongitudinal(DapodikObject):
     id_ruang: str
     semester_id: str
