@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime
 from typing import Optional
 from dapodik import DapodikObject, Sekolah, SumberDanaSekolah
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('blockgrant_id', sekolah=Sekolah, sumber_dana=SumberDanaSekolah)
-@dataclass(eq=False)
+@set_meta("blockgrant_id", sekolah=Sekolah, sumber_dana=SumberDanaSekolah)
+@attr.dataclass
 class BlockGrant(DapodikObject):
     blockgrant_id: str
     sekolah_id: str
