@@ -1,12 +1,12 @@
-from dataclasses import dataclass
+import attr
 from datetime import datetime, date
 from typing import Optional
 from dapodik import DapodikObject, TahunAjaran
 from dapodik.utils.decorator import set_meta
 
 
-@set_meta('semester_id', tahun_ajaran=TahunAjaran)
-@dataclass(eq=False)
+@set_meta("semester_id", tahun_ajaran=TahunAjaran)
+@attr.dataclass
 class Semester(DapodikObject):
     semester_id: str
     tahun_ajaran_id: str
